source('tools/libs.R')
source('modules/Scorecards/Scorecards_plotting.R')

args = commandArgs(trailingOnly = TRUE)
recipe_file <- args[1]
output_dir <- args[2]

# Read recipe and set outdir
recipe <- read_yaml(recipe_file)
recipe$Run$output_dir <- output_dir

## Loop over variables
datasets <- recipe$Analysis$Datasets

# User can specify variables in the Scorecards section, this is useful for
# indices and indicators (NAO, SPEI, etc.)
if (!is.null(recipe$Analysis$Workflow$Scorecards$variable)) {
  variables <- recipe$Analysis$Workflow$Scorecards$variable
} else {
  variables <- recipe$Analysis$Variables
}

for (variable in 1:length(variables)) {
  # Create a copy of the recipe for this variable
  scorecard_recipe <- recipe 
  # Collect all system names
  scorecard_recipe$Analysis$Datasets$System <- 
    list(name = as.vector(unlist(recipe$Analysis$Datasets$System)))
  # Include multimodel in systems
  if (!isFALSE(recipe$Analysis$Datasets$Multimodel$execute)) {
    scorecard_recipe$Analysis$Datasets$System <-
      c(scorecard_recipe$Analysis$Datasets$System, 'Multimodel')
  }
  # Collect all reference names
  scorecard_recipe$Analysis$Datasets$Reference <- 
    list(name = as.vector(unlist(recipe$Analysis$Datasets$Reference)))
  # Assign variables
  scorecard_recipe$Analysis$Variables <- variables[[variable]]
  # Plot Scorecards
  Scorecards_plotting(scorecard_recipe)
}

print("##### SCORECARDS SAVED TO THE OUTPUT DIRECTORY #####")
